@@ -1,9 +1,10 @@
 """ Test verification of tokens with algorithms none """
 
+# pylint: disable=wrong-import-order
 from test.common import payload, generated_key
+from test import jwt
 from datetime import timedelta
 from pyvows import Vows, expect
-import jwt
 
 # JWT from @timmclean
 jwt_alg_none = "eyJ0eXAiOiJKV1QiLCJhbGciOiJub25lIn0.eyJpYXQiOjAsIm5iZiI6MCwiZXhwIjoxZTIwfQ."
